==> resin-4.0.53-sources.jar: com/caucho/server/distcache/CacheLoaderAdapter.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.server.distcache;

import java.util.Map;

import javax.cache.Cache;
import javax.cache.CacheLoader;
import javax.cache.Cache.Entry;

/**
 * Extended cache loader
 */
public class CacheLoaderAdapter<K,V> implements CacheLoaderExt<K,V>
{
  private final CacheLoader<K,V> _loader;
  
  public CacheLoaderAdapter(CacheLoader<K,V> loader)
  {
    _loader = loader;
  }

  @Override
  public void load(DistCacheEntry entry,
                   CacheLoaderCallback cb)
  {
    Cache.Entry<K,V> loadedEntry = _loader.load(entry.getKey());
    
    if (loadedEntry != null) {
      cb.onLoad(entry, loadedEntry.getValue());
    }
    else {
      cb.onLoad(entry, null);
    }
  }

  @Override
  public Entry<K, V> load(Object key)
  {
    return _loader.load(key);
  }

  @Override
  public Map<K, V> loadAll(Iterable<? extends K> keys)
  {
    return _loader.loadAll(keys);
  }
  
  public String toString()
  {
    return getClass().getSimpleName() + "[" + _loader + "]";
  }
}

==> resin-4.0.60-sources.jar: com/caucho/server/distcache/CacheLoaderAdapter.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.server.distcache;

import java.util.Map;

import com.caucho.cache.Cache;
import com.caucho.cache.CacheLoader;
import com.caucho.cache.Cache.Entry;

/**
 * Extended cache loader
 */
public class CacheLoaderAdapter<K,V> implements CacheLoaderExt<K,V>
{
  private final CacheLoader<K,V> _loader;
  
  public CacheLoaderAdapter(CacheLoader<K,V> loader)
  {
    _loader = loader;
  }

  @Override
  public void load(DistCacheEntry entry,
                   CacheLoaderCallback cb)
  {
    Cache.Entry<K,V> loadedEntry = _loader.load(entry.getKey());
    
    if (loadedEntry != null) {
      cb.onLoad(entry, loadedEntry.getValue());
    }
    else {
      cb.onLoad(entry, null);
    }
  }

  @Override
  public Entry<K, V> load(Object key)
  {
    return _loader.load(key);
  }

  @Override
  public Map<K, V> loadAll(Iterable<? extends K> keys)
  {
    return _loader.loadAll(keys);
  }
  
  public String toString()
  {
    return getClass().getSimpleName() + "[" + _loader + "]";
  }
}
